@@ -2,8 +2,8 @@
 """
 :Author: HuangJingCan
 :Date: 2020-06-02 11:08:39
-:LastEditTime: 2021-04-15 15:12:43
-:LastEditors: HuangJingCan
+@LastEditTime: 2021-10-08 14:48:16
+@LastEditors: HuangJianYi
 :description: 订单相关
 """
 from seven_cloudapp.handlers.seven_base import *
@@ -421,6 +421,7 @@ class PrizeOrderImportHandler(SevenBaseHandler):
         content_json = self.json_loads(content)
 
         prize_order_model = PrizeOrderModel(context=self)
+        prize_roster_model = PrizeRosterModel(context=self)
 
         order_no_index = -1
         express_no_index = -1
@@ -458,5 +459,6 @@ class PrizeOrderImportHandler(SevenBaseHandler):
                 update_sql = "order_status=1,express_no=%s,express_company=%s,deliver_date=%s,modify_date=%s"
                 params = [express_no, express_company, self.get_now_datetime(), self.get_now_datetime(), order_no, act_id]
                 prize_order_model.update_table(update_sql, "order_no=%s and act_id=%s", params=params)
+                prize_roster_model.update_table("order_status=1", "order_no=%s and act_id=%s", [order_no, act_id])
 
         return self.reponse_json_success()
\ No newline at end of file
